@@ -1,26 +1,26 @@
 package Module::Install::Msgfmt;
 
+use 5.008005;
 use strict;
-use File::Spec;
+use warnings;
+use File::Spec            ();
 use Module::Install::Base ();
-use Module::Install::Share;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 our @ISA     = 'Module::Install::Base';
 
 sub install_share_with_mofiles {
-	my @orig      = (@_);
 	my $self      = shift;
+	my @orig      = (@_);
 	my $class     = ref($self);
 	my $prefix    = $self->_top->{prefix};
 	my $name      = $self->_top->{name};
-	my $dir       = @_ ? pop : 'share';
+	my $dir       = @_ ? pop   : 'share';
 	my $type      = @_ ? shift : 'dist';
 	my $module    = @_ ? shift : '';
-	$self->build_requires( 'Locale::Msgfmt' => '0.14' );
-	install_share(@orig);
+	$self->build_requires( 'Locale::Msgfmt' => '0.15' );
+	$self->install_share(@orig);
 	my $distname = "";
-
 	if ( $type eq 'dist' ) {
 		$distname = $self->name;
 	} else {
@@ -34,3 +34,5 @@ config ::
 
 END_MAKEFILE
 }
+
+1;
